Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CommonPrefixLength ¶
CommonPrefixLength returns the length of the common prefix shared between two slices of Nibbles
Types ¶
type Nibble ¶
type Nibble byte
func CompactEncoding ¶
CompactEncoding adds a nibble prefix to a slice of nibbles to indicate its type and make its length even
func RemoveCompactEncoding ¶
RemoveCompactEncoding removes the compact encoding from the nibble slice
Click to show internal directories.
Click to hide internal directories.